import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/material.dart';

enum Size {
  BANNER,
  LARGE_BANNER,
  MEDIUM_RECTANGLE,
  FULL_BANNER,
  LEADER_BOARD,
  SMART_BANNER,
}

enum Gravity {
  TOP,
  BOTTOM
}
class FlutterAdmob {

  static const MethodChannel _channel =
      const MethodChannel('flutter_admob');
  static AdmobBanner banner = AdmobBanner(_channel);

  static AdmobInterstital interstital =AdmobInterstital(_channel);

  static Future<void> init (String appId) async {
    await _channel.invokeMethod('init', {"app_id": appId});
  }

  
  static Future<void> showRewardVideo(String unitId) async {
     await _channel.invokeMethod("show_rewardvideo", {
      "unit_id":unitId,
    });
  }

}

class AdmobBanner {
  MethodChannel _channel;

  AdmobBanner(MethodChannel channel) {
    this._channel = channel;
  }

  Future<void> show(String unitId, {
    Size size, 
    Gravity gravity, 
    int width = 0,
    int height = 0,
    double anchorOffset
  })  async {
    await _channel.invokeMethod("show_banner", {
      "unit_id":unitId,
      "size": size.index,
      "width": width,
      "height": height,
      "gravity":gravity.index,
      "anchor_offset":anchorOffset,
    });
  }

  Future<void> hide() async {
    await _channel.invokeMethod("hide_banner", {});
  }
}

class AdmobInterstital {
  MethodChannel _channel;

  AdmobInterstital(MethodChannel channel) {
    _channel = channel;
    _channel.setMethodCallHandler((handler) {
      print("hander : $handler");
      switch (handler.method) {
        case "interstitialDidReceiveAd":
          print("interstitialDidReceiveAd");
          break;
        case "didFailToReceiveAdWithError":
          print("didFailToReceiveAdWithError");
          break;
        case "interstitialWillDismissScreen":
          print("interstitialWillDismissScreen");
          break;
        case "interstitialDidDismissScreen":
          print("interstitialDidDismissScreen");
          break;
        default:
      }
    });
  }
  
  Future<void> show(String unitId) async {
    await _channel.invokeMethod("show_interstitial", {
      "unit_id":unitId,
    });
  }
}